@@ -197,6 +197,11 @@ class XMLStream(asyncio.Protocol):
     :param sorted_attributes: Sort attributes deterministically on output
         (debug option; not part of the public interface)
     :type sorted_attributes: :class:`bool`
+    :param default_namespace: Set the default namespace to advertise on the
+        stream header.
+    :type default_namespace: :class:`str`
+    :param from_: The value of the from attribute of the stream header.
+    :tpye from_: :class:`~aioxmpp.JID` or :data:`None`
     :param base_logger: Parent logger for this stream
     :type base_logger: :class:`logging.Logger`
 
@@ -327,8 +332,11 @@ class XMLStream(asyncio.Protocol):
                  features_future=None,
                  sorted_attributes=False,
                  base_logger=logging.getLogger("aioxmpp"),
+                 default_namespace="jabber:client",
+                 from_=None,
                  loop=None):
         self._to = to
+        self._from = from_
         self._sorted_attributes = sorted_attributes
         self._logger = base_logger.getChild("XMLStream")
         self._transport = None
@@ -341,6 +349,7 @@ class XMLStream(asyncio.Protocol):
             self._error_futures.append(features_future)
         self._smachine = statemachine.OrderedStateMachine(State.READY)
         self._transport_closing = False
+        self._default_namespace = default_namespace
         self._monitor = utils.AlivenessMonitor(self._loop)
         self._monitor.on_deadtime_hard_limit_tripped.connect(
             self._deadtime_hard_limit_triggered
@@ -489,7 +498,7 @@ class XMLStream(asyncio.Protocol):
         except Exception:
             self._logger.exception(
                 "unexpected exception while parsing stanza"
-                " bubbled up through parser. stream so ded.")
+                " bubbled up through parser. stream so dead.")
             raise errors.StreamError(
                 condition=errors.StreamErrorCondition.INTERNAL_SERVER_ERROR,
                 text="Internal error while parsing XML. Client logs have more"
@@ -558,8 +567,8 @@ class XMLStream(asyncio.Protocol):
             # these states are fine, common actions below
             pass
         else:
-            self._logger.warn("unexpected eof_received (in %s state)",
-                              self._smachine.state)
+            self._logger.warning("unexpected eof_received (in %s state)",
+                                 self._smachine.state)
             # common actions below
 
         self._smachine.state = State.CLOSING_STREAM_FOOTER_RECEIVED
@@ -635,7 +644,8 @@ class XMLStream(asyncio.Protocol):
         self._writer = xml.XMLStreamWriter(
             dest,
             self._to,
-            nsmap={None: "jabber:client"},
+            nsmap={None: self._default_namespace},
+            from_=self._from,
             sorted_attributes=self._sorted_attributes)
 
     def reset(self):
@@ -706,7 +716,7 @@ class XMLStream(asyncio.Protocol):
 
         .. versionchanged:: 0.9
 
-           Exceptions occuring during serialisation of `obj` are re-raised and
+           Exceptions occurring during serialisation of `obj` are re-raised and
            *no* content is sent over the stream. The stream is still valid and
            usable afterwards.
 
@@ -760,7 +770,7 @@ class XMLStream(asyncio.Protocol):
 
     def features_future(self):
         """
-        Return a future which will recieve the next XML stream features (as
+        Return a future which will receive the next XML stream features (as
         return value) or the next XML stream error (as exception), whichever
         happens first.
 
@@ -889,7 +899,7 @@ async def send_and_wait_for(xmlstream, send, wait_for,
             ],
             timeout=timeout,
             return_when=asyncio.FIRST_COMPLETED,
-            loop=xmlstream._loop)
+        )
 
         for other_fut in pending:
             other_fut.cancel()
@@ -927,6 +937,8 @@ def send_stream_error_and_close(
         condition=condition,
         text=text))
     if custom_condition is not None:
-        logger.warn("custom_condition argument to send_stream_error_and_close"
-                    " not implemented")
+        logger.warning(
+            "custom_condition argument to send_stream_error_and_close"
+            " not implemented",
+        )
     xmlstream.close()
